Zadane.pl - Uczymy się w grupie
Description: Zadane.pl to platforma social learningowa dzięki której otrzymasz pomoc w zadaniu domowym. Dołącz do nas i ucz się w grupie.

# Uczymy się w grupie

## Pomagamy sobie nawzajem w zadaniach domowych. Jest nas już tak dużo, że 80% pytań otrzymuje odpowiedź w ciągu 10 minut ...

Jak to działa? Dołącz do nas!

### Pytania ze wszystkich przedmiotów

+0 nowych pytań
Kuba5813 Początkujący

- Matematyka
- 9 pkt
- 2 min. temu

1.Zastosuj wzory skroconego mnozenia. a) (x-3y) do potegi 2 b) (a+5b ) do potegi 2 c) (2x+8y) do potegi 2 d) (6a+3c)(6a-3c) e) (^6x-^2y)(^2y+^6x) f) (1/8x-9) do potegi 2 2. Uprosc...
SmartLuna Rozwiązujący

- Polski
- 50 pkt
- 4 min. temu

Napisz charakterystyke Julii jako postaci dynamicznej. Poszers swoje rozważaniao konteksty malarskie. Prosze znikąd nie kopiować! Daje NAJ!
Anorii Ambitny

- Język angielski
- 5 pkt
- 6 min. temu

Proszę o pomoc! at/by the sea
Jakubadamkiewi Początkujący

- Matematyka
- 5 pkt
- 9 min. temu

Prosz szybko dam dzjękuje ps z obliczeniami
Kot930 Początkujący

- Polski
- 15 pkt
- 10 min. temu

Nazwę część mowy. Określę formy gramatyczne: np. zrobię- os.1 lp. czas przyszły prosty, tryb orze., strona czynna chciałby- się- coś- ktoś- na- i- ale- on- są- pagórkowaty- wesoło- ...
Moniiak Ambitny

- Matematyka
- 5 pkt
- 10 min. temu

Przekatna podstawy oatroslupa prawidlowego czworokatnego ma dlugosc pierwiastek z 72cm. wysokosc sciany bocznej ostroslupa jest taka jak krawedz podstawy. wykonaj odpowiedni rysunek I oblicz...
Adrian7891 Początkujący

- Historia
- 5 pkt
- 12 min. temu

Potrzebuje rozwiazania skrutu ,,ZSRR"
Lola2510 Początkujący

- Polski
- 5 pkt
- 17 min. temu

Opisz bajkę Pan i pies, ptaszki w klatce Ignacego Krasickiego
Michałxdpozdro6... Początkujący

- Fizyka
- 25 pkt
- 19 min. temu

Wzór na siłę dajęęę naj
Oliwiakowalczy1 Rozwiązujący

- Polski
- 5 pkt
- 21 min. temu

Jestem nauczycielką i jak sprawdzałam to było kilka błędów językowych i gramatycznych no i właśniemoja uczennica to przepisała i dostała 1
Sarapham3012 Początkujący

- Przedsiębiorczość
- 5 pkt
- 31 min. temu

Your friend tried to call you yesterday but you didn't answer. what were you doing?
Rafcio25 Początkujący

- Polski
- 25 pkt
- 35 min. temu

Przygotuj 7 minutową wypowiedź ustną na podany temat. Na podstawie wiersza anny kamieńskiej "Hiob i młodzieniec" rozważ czy zawarty w nich portret młode go pokolenia jest prawdziwy, czy może to...
Tygrysek200982 Początkujący

- Polski
- 5 pkt
- 44 min. temu

Rozwiń wybrany cytat ,,Im cięższa walka , tym wspanialsze zwycięstwo,,
Tadekx1 Ambitny

- Polski
- 5 pkt
- 50 min. temu

Rola nawiązań literackich.W jaki sposób legenda opowiadana przez Węgielka wiąże się z losami Wokulskiego.
Patrykmazur55 Początkujący

- Religia
- 5 pkt
- 52 min. temu

POMOCY MA KTOS TEKS JÓZEFA NA KOLENDE NA JUTRO !!!
Memonka123 Początkujący

- Historia
- 5 pkt
- 56 min. temu

Przyjrzyj się zamieszczonej mapie. Następnie wykonaj polecenia. *Zamaluj obszar objęty powstaniem wielkopolskim. *Zapisz w odpowiednich miejscach na mapie nazwy państw graniczących z II...
Paulabdg94 Początkujący

- Polski
- 5 pkt
- 1 godz. temu

Napisz wywiad środowiskowy pierwszej pomocy przedmedycznej(wiek,płeć,czy przechodził kurs,czy udzielał 1 pomocy przedmedycznej)
Nissan333 Początkujący

- Polski
- 10 pkt
- 1 godz. temu

Napisz recenzję spektaklu pt. W Imię Przyjaźni Pilnie potrzebuję za 30 minut
Muszka91 Początkujący

- Polski
- 20 pkt
- 1 godz. temu

Mamy napisać - O przetrwaniu. Rozwiąż sposoby przedstawienia i realizacji tego zagadnienia na podstawie załączonej reprodukcji oraz 2 innych tekstów kultury. Mówiące o nietrwalosci Piter Class...
Problemyangol1 Początkujący

- Język angielski
- 15 pkt
- 1 godz. temu

Proszę odpowiedzieć na pytania. Odpowiedzi powinny być krótkie i zawierać dwa powody :) 1. What sorts of things do people write in their diaries? 2. Do you know anyone who keeps a private...
ładowanie...
Pokaż więcej
Dodaj pytanie

### Najlepsi rozwiązujący

- Ranking dzienny
- Ranking tygodniowy
- Ranking miesięczny
- Ranking kwartalny

1. #1 Ghe 151 pkt
2. #2 MrPolygon 141 pkt
3. #3 Rezit 90 pkt
4. #4 Thisnatala 85 pkt
5. #5 Ankaz 70 pkt
6. #6 Misiaczeks1... 68 pkt
7. #7 GreenEyed91... 61 pkt
8. #8 Seb12 59 pkt
9. #9 Piotrsk6 58 pkt
10. #10 Rekah4 57 pkt
11. #11 Bartosiakpa... 57 pkt
12. #12 Roksana8080 53 pkt
13. #13 Cleomartss 50 pkt
14. #14 Poziomka777 43 pkt
15. #15 Bar146 42 pkt
16. #16 Karola55555 41 pkt
17. #17 MartaVito 38 pkt
18. #18 Dywan 35 pkt
19. #19 Zuzu2345 31 pkt
20. #20 MałaŻyrafa 30 pkt

rozwiń

### Zapytaj o zadanie za darmo!

Dodaj pytanie

## Jak działa Zadane.pl ?

Lubisz polski ale nie radzisz sobie z fizyką?

Ty pomóżesz komuś , a jeden z 2 mln uczniów pomoże Tobie